=== modified file 'NEWS'
--- NEWS	2006-12-12 02:28:39 +0000
+++ NEWS	2006-12-13 08:19:49 +0000
@@ -54,6 +54,9 @@
     * bzr now supports Win32 UNC path (e.g. \\HOST\path). 
       (Alexander Belchenko, #57869)
 
+    * Win32-specific: output of cat, bundle and diff commands don't mangle
+      line-endings (Alexander Belchenko, #55276)
+
 
 bzr 0.13  2006-12-05
     

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-12-12 01:23:40 +0000
+++ bzrlib/builtins.py	2006-12-13 08:19:49 +0000
@@ -1218,6 +1218,7 @@
     takes_options = ['revision', 'diff-options', 'prefix']
     aliases = ['di', 'dif']
     encoding_type = 'exact'
+    binary_stdout = True
 
     @display_command
     def run(self, revision=None, file_list=None, diff_options=None,
@@ -1738,6 +1739,7 @@
 
     takes_options = ['revision', 'name-from-revision']
     takes_args = ['filename']
+    binary_stdout = True
 
     @display_command
     def run(self, filename, revision=None, name_from_revision=False):

=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/bundle/commands.py	2006-10-16 01:25:46 +0000
+++ bzrlib/bundle/commands.py	2006-12-13 08:19:49 +0000
@@ -98,6 +98,7 @@
                             type=unicode)]
     takes_args = ['base?']
     aliases = ['bundle']
+    binary_stdout = True
 
     def run(self, base=None, revision=None, output=None, remember=False):
         from bzrlib import user_encoding

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2006-12-12 00:00:15 +0000
+++ bzrlib/commands.py	2006-12-13 08:19:49 +0000
@@ -214,11 +214,18 @@
             replace - put in a bogus character (typically '?')
             exact - do not encode sys.stdout
 
+    binary_stdout
+        Typically output of Command use native line-endings on each
+        platform. This leads to problems on win32 with some commands,
+        because Windows convert LF to CRLF.
+        If this attribute is True then output forced to binary
+        (without such conversion) on Windows
     """
     aliases = []
     takes_args = []
     takes_options = []
     encoding_type = 'strict'
+    binary_stdout = False
 
     hidden = False
     
@@ -243,6 +250,11 @@
         """Return a file linked to stdout, which has proper encoding."""
         assert self.encoding_type in ['strict', 'exact', 'replace']
 
+        if sys.platform == 'win32' and self.binary_stdout:
+            if hasattr(sys.stdout, 'fileno'):
+                import msvcrt
+                msvcrt.setmode(sys.stdout.fileno(), os.O_BINARY)
+
         # Originally I was using self.stdout, but that looks
         # *way* too much like sys.stdout
         if self.encoding_type == 'exact':

